@@ -6,7 +6,7 @@ use strict;
 use warnings;
 
 # set up version info
-our $VERSION= '0.12';
+our $VERSION= '0.13';
 
 # we need this otherwise nothing works
 use Data::Alias qw( alias copy );
@@ -179,11 +179,10 @@ sub reuse (@) {
                                 $id= $U;
                             }
                         }
-
                         # huh?
                         else {
-                            croak "Cannot reuse '$reftype' references";
-                        }
+                        	$id = md5( $S . $_ );
+			}
 
 =for Explanation:
      When called in void context, perl may actually have used a memory location
@@ -202,7 +201,7 @@ sub reuse (@) {
                     # done handling this ref
                     delete $handling{$_};
                 }
-
+		
                 # not a ref, but now already in store
                 elsif ( exists $reuse{$_} ) {
                 }
@@ -412,7 +411,7 @@ Data::Reuse - share constant values with Data::Alias
 
 =head1 VERSION
 
-This documentation describes version 0.12.
+This documentation describes version 0.13.
 
 =head1 SYNOPSIS
 
